@@ -2,14 +2,7 @@
 Define exceptions thrown by `django-render-static`
 """
 
-__all__ = ['PlaceholderNotFound', 'URLGenerationFailed']
-
-
-class PlaceholderNotFound(Exception):
-    """
-    Thrown by `urls_to_js` when a reversible URL requires placeholders in order ot be reversed
-    but none are registered.
-    """
+__all__ = ['URLGenerationFailed']
 
 
 class URLGenerationFailed(Exception):
@@ -17,3 +10,10 @@ class URLGenerationFailed(Exception):
     Thrown by `urls_to_js` under any circumstance where URL generation fails for a specific
     fully qualified URL name.
     """
+
+
+class ReversalLimitHit(Exception):
+    """
+    Thrown by `urls_to_js` under any circumstance where the configured maximum number of tries has
+    been hit when attempting to reverse a URL.
+    """
